pub fn pack_planar_image<T: TensorElement, const CHANNELS: usize>(
image: PlanarImageView<'_, T, CHANNELS>,
) -> Result<TensorBuffer, TensorError>Expand description
Explicitly packs a possibly strided planar image view into an owned CHW tensor.
pub fn pack_planar_image<T: TensorElement, const CHANNELS: usize>(
image: PlanarImageView<'_, T, CHANNELS>,
) -> Result<TensorBuffer, TensorError>Explicitly packs a possibly strided planar image view into an owned CHW tensor.