DlpackImport

Struct DlpackImport 

pub struct DlpackImport { /* private fields */ }
Validated owner of a DLPack producer’s managed tensor.

Implementations

Source

impl DlpackImport

pub unsafe fn from_raw(raw: *mut c_void) -> Result<Self, DlpackError>

Takes deleter ownership of a DLPack managed tensor and validates its host view.

Safety

raw must be a live, exclusively transferred DLManagedTensorVersioned* produced according to DLPack. The caller must not use or delete it after this call, whether validation succeeds or fails.

pub unsafe fn from_legacy_raw(raw: *mut c_void) -> Result<Self, DlpackError>

Takes deleter ownership of a legacy DLPack managed tensor.

Safety

raw must be a live, exclusively transferred legacy DLManagedTensor*.

pub const fn version(&self) -> (u32, u32)

Returns producer ABI major and minor versions.

pub const fn flags(&self) -> u64

Returns raw DLPack flags.

pub const fn descriptor(&self) -> &TensorDescriptor

Returns validated tensor metadata.

pub fn view(&self) -> Result<TensorView<'_>, DlpackError>

Borrows the imported host allocation without copying it.