pub struct DlpackImport { /* private fields */ }Expand description
Validated owner of a DLPack producer’s managed tensor.
Implementations
Sourceimpl DlpackImport
impl DlpackImport
Sourcepub unsafe fn from_raw(raw: *mut c_void) -> Result<Self, DlpackError>
pub unsafe fn from_raw(raw: *mut c_void) -> Result<Self, DlpackError>
Takes deleter ownership of a DLPack managed tensor and validates its host view.
Safety
raw must be a live, exclusively transferred DLManagedTensorVersioned*
produced according to DLPack. The caller must not use or delete it after
this call, whether validation succeeds or fails.
Sourcepub unsafe fn from_legacy_raw(raw: *mut c_void) -> Result<Self, DlpackError>
pub unsafe fn from_legacy_raw(raw: *mut c_void) -> Result<Self, DlpackError>
Takes deleter ownership of a legacy DLPack managed tensor.
Safety
raw must be a live, exclusively transferred legacy DLManagedTensor*.
Sourcepub const fn descriptor(&self) -> &TensorDescriptor
pub const fn descriptor(&self) -> &TensorDescriptor
Returns validated tensor metadata.
Sourcepub fn view(&self) -> Result<TensorView<'_>, DlpackError>
pub fn view(&self) -> Result<TensorView<'_>, DlpackError>
Borrows the imported host allocation without copying it.